@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: yesod-persistent
 version: 1.4.0.4
-id: yesod-persistent-1.4.0.4-46b19a60c1c766dabb361044b5599141
-key: yesod_IrWb0ad2klrCzX8H0HLAMd
+id: yesod-persistent-1.4.0.4-05d2e78a4f4be2f611edc21702f1c928
+key: yesod_G6KlTKEhujlITDPyMCTHXD
 license: MIT
 maintainer: Michael Snoyman <michael@snoyman.com>
 stability: Stable
@@ -20,17 +20,17 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-persistent-1.4.0.4
 library-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-persistent-1.4.0.4
 data-dir: /usr/share/arm-linux-ghc-7.10.3/yesod-persistent-1.4.0.4
-hs-libraries: HSyesod-persistent-1.4.0.4-IrWb0ad2klrCzX8H0HLAMd
+hs-libraries: HSyesod-persistent-1.4.0.4-G6KlTKEhujlITDPyMCTHXD
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     blaze-builder-0.4.0.1-0c3e4ae1ea19a65d81d24f4a911c903b
-    conduit-1.2.6.4-0dfd87f475e845002478c37d3a30df1e
-    persistent-2.2.4.1-515160ea71a89b76b70a56c63b058aa3
-    persistent-template-2.1.6-42489148129b2fa03f15ca76243f3923
-    resource-pool-0.2.3.2-1d704fbdc1706c3584f9663671e9b735
-    resourcet-1.1.7.3-3e7ca03abacc332d28328c69bbd74cd4
+    conduit-1.2.6.4-9cbf21b79aba616188d311eceb1fecef
+    persistent-2.2.4.1-840a8f388c4f74e927e97d9dd2d8494d
+    persistent-template-2.1.6-6446adcdac00e4cf9aeae54844fe611d
+    resource-pool-0.2.3.2-4273363c3eb17da3d6b84d801cb4d318
+    resourcet-1.1.7.3-7c6bcbec462b80120c27277d178fc6db
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
-    yesod-core-1.4.20-0795e5dd1fccda51b978355252f3f0a8
+    yesod-core-1.4.20.1-8dce2c1559c72b98aae15f98b85f32e0
 haddock-interfaces: /usr/share/doc/haskell-yesod-persistent/html/yesod-persistent.haddock
 haddock-html: /usr/share/doc/haskell-yesod-persistent/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
